@@ -11,7 +11,7 @@ use umbra::optional;
 use crate::{
     color::{ColorTheme, OptionalColorTheme},
     keybind::KeyBind,
-    Result,
+    CommitOrderType, GraphWidthType, ImageProtocolType, Result,
 };
 
 const XDG_CONFIG_HOME_ENV_NAME: &str = "XDG_CONFIG_HOME";
@@ -30,7 +30,10 @@ pub fn load() -> Result<(
     let config = match config_file_path_from_env() {
         Some(user_path) => {
             if !user_path.exists() {
-                let msg = format!("Config file not found: {user_path:?}");
+                let msg = format!(
+                    "Config file specified by ${CONFIG_FILE_ENV_NAME} environment variable not found: {}",
+                    user_path.display()
+                );
                 return Err(msg.into());
             }
             read_config_from_path(&user_path)
@@ -92,12 +95,22 @@ struct Config {
 #[optional(derives = [Deserialize])]
 #[derive(Debug, Default, Clone, PartialEq, Eq)]
 pub struct CoreConfig {
+    #[nested]
+    pub option: CoreOptionConfig,
     #[nested]
     pub search: CoreSearchConfig,
     #[nested]
     pub user_command: CoreUserCommandConfig,
 }
 
+#[optional(derives = [Deserialize])]
+#[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
+pub struct CoreOptionConfig {
+    pub protocol: Option<ImageProtocolType>,
+    pub order: Option<CommitOrderType>,
+    pub graph_width: Option<GraphWidthType>,
+}
+
 #[optional(derives = [Deserialize])]
 #[derive(Debug, Clone, PartialEq, Eq, SmartDefault)]
 pub struct CoreSearchConfig {
@@ -296,6 +309,11 @@ mod tests {
         let actual = Config::default();
         let expected = Config {
             core: CoreConfig {
+                option: CoreOptionConfig {
+                    protocol: None,
+                    order: None,
+                    graph_width: None,
+                },
                 search: CoreSearchConfig {
                     ignore_case: false,
                     fuzzy: false,
@@ -360,6 +378,10 @@ mod tests {
     #[test]
     fn test_config_complete_toml() {
         let toml = r##"
+            [core.option]
+            protocol = "kitty"
+            order = "topo"
+            graph_width = "single"
             [core.search]
             ignore_case = true
             fuzzy = true
@@ -392,6 +414,11 @@ mod tests {
         let actual: Config = toml::from_str::<OptionalConfig>(toml).unwrap().into();
         let expected = Config {
             core: CoreConfig {
+                option: CoreOptionConfig {
+                    protocol: Some(ImageProtocolType::Kitty),
+                    order: Some(CommitOrderType::Topo),
+                    graph_width: Some(GraphWidthType::Single),
+                },
                 search: CoreSearchConfig {
                     ignore_case: true,
                     fuzzy: true,
@@ -469,6 +496,11 @@ mod tests {
         let actual: Config = toml::from_str::<OptionalConfig>(toml).unwrap().into();
         let expected = Config {
             core: CoreConfig {
+                option: CoreOptionConfig {
+                    protocol: None,
+                    order: None,
+                    graph_width: None,
+                },
                 search: CoreSearchConfig {
                     ignore_case: false,
                     fuzzy: false,
