@@ -8,7 +8,7 @@ use ratatui::{
 use crate::{
     color::ColorTheme,
     config::UiConfig,
-    event::{AppEvent, Sender, UserEvent},
+    event::{AppEvent, Sender, UserEvent, UserEventWithCount},
     git::{Commit, FileChange, Ref},
     protocol::ImageProtocol,
     widget::{
@@ -58,13 +58,40 @@ impl<'a> DetailView<'a> {
         }
     }
 
-    pub fn handle_event(&mut self, event: UserEvent, _: KeyEvent) {
+    pub fn handle_event(&mut self, event_with_count: UserEventWithCount, _: KeyEvent) {
+        let event = event_with_count.event;
+        let count = event_with_count.count;
+
         match event {
             UserEvent::NavigateDown => {
-                self.commit_detail_state.scroll_down();
+                for _ in 0..count {
+                    self.commit_detail_state.scroll_down();
+                }
             }
             UserEvent::NavigateUp => {
-                self.commit_detail_state.scroll_up();
+                for _ in 0..count {
+                    self.commit_detail_state.scroll_up();
+                }
+            }
+            UserEvent::PageDown => {
+                for _ in 0..count {
+                    self.commit_detail_state.scroll_page_down();
+                }
+            }
+            UserEvent::PageUp => {
+                for _ in 0..count {
+                    self.commit_detail_state.scroll_page_up();
+                }
+            }
+            UserEvent::HalfPageDown => {
+                for _ in 0..count {
+                    self.commit_detail_state.scroll_half_page_down();
+                }
+            }
+            UserEvent::HalfPageUp => {
+                for _ in 0..count {
+                    self.commit_detail_state.scroll_half_page_up();
+                }
             }
             UserEvent::GoToTop => {
                 self.commit_detail_state.select_first();
@@ -78,6 +105,9 @@ impl<'a> DetailView<'a> {
             UserEvent::FullCopy => {
                 self.copy_commit_hash();
             }
+            UserEvent::UserCommandViewToggle(n) => {
+                self.tx.send(AppEvent::OpenUserCommand(n));
+            }
             UserEvent::HelpToggle => {
                 self.tx.send(AppEvent::OpenHelp);
             }
