@@ -20,7 +20,7 @@ fn straight_001() -> TestResult {
 
     let mut base_date = Utc.with_ymd_and_hms(2024, 1, 1, 1, 2, 3).unwrap();
     for i in 1..=100 {
-        let msg = &format!("{:03}", i);
+        let msg = &format!("{i:03}");
         let date = &base_date.format("%Y-%m-%d").to_string();
         git.commit(msg, date);
         base_date = base_date.checked_add_days(Days::new(1)).unwrap();
@@ -895,6 +895,47 @@ fn orphan_002() -> TestResult {
     Ok(())
 }
 
+#[test]
+fn head_001() -> TestResult {
+    // Test case for detached HEAD
+    let dir = tempfile::tempdir()?;
+    let repo_path = dir.path();
+
+    let git = &GitRepository::new(repo_path);
+
+    git.init();
+
+    git.commit("001", "2024-01-01");
+    git.commit("002", "2024-01-02");
+
+    git.checkout_b("10");
+    git.commit("011", "2024-01-03");
+    git.commit("012", "2024-01-04");
+
+    let hash = git.rev_parse_head();
+
+    git.checkout("master");
+    git.commit("003", "2024-01-05");
+    git.commit("004", "2024-01-06");
+
+    git.checkout(hash.as_str());
+    git.branch_d("10");
+
+    git.log();
+
+    let options = &[
+        GenerateGraphOption::new("head_001_chrono", git::SortCommit::Chronological),
+        GenerateGraphOption::new("head_001_topo", git::SortCommit::Topological),
+    ];
+
+    copy_git_dir(repo_path, "head_001");
+
+    generate_and_output_graph_images(repo_path, options);
+    assert_graph_images(options);
+
+    Ok(())
+}
+
 #[test]
 fn complex_001() -> TestResult {
     let dir = tempfile::tempdir()?;
@@ -983,7 +1024,7 @@ struct GitRepository<'a> {
 }
 
 impl GitRepository<'_> {
-    fn new(path: &Path) -> GitRepository {
+    fn new(path: &'_ Path) -> GitRepository<'_> {
         GitRepository { path }
     }
 
@@ -1027,13 +1068,18 @@ impl GitRepository<'_> {
         self.run(&["stash", "--include-untracked"], &datetime_str);
     }
 
+    fn rev_parse_head(&self) -> String {
+        let output = self.run(&["rev-parse", "HEAD"], "");
+        String::from_utf8(output.stdout).unwrap().trim().to_string()
+    }
+
     fn log(&self) {
         let output = self.run(&["log", "--pretty=format:%h %s", "--graph", "--all"], "");
         println!("{}", String::from_utf8(output.stdout).unwrap())
     }
 
     fn run(&self, args: &[&str], datetime_str: &str) -> std::process::Output {
-        Command::new("git")
+        let out = Command::new("git")
             .args(args)
             .current_dir(self.path)
             .env("GIT_AUTHOR_NAME", "Author Name")
@@ -1045,7 +1091,9 @@ impl GitRepository<'_> {
             .env("GIT_CONFIG_NOSYSTEM", "true")
             .env("HOME", "/dev/null")
             .output()
-            .unwrap_or_else(|_| panic!("failed to execute git {}", args.join(" ")))
+            .unwrap_or_else(|_| panic!("failed to execute git {}", args.join(" ")));
+        println!("git {}: returned {}", args.join(" "), out.status,);
+        out
     }
 }
 
@@ -1063,7 +1111,7 @@ struct GenerateGraphOption<'a> {
 }
 
 impl GenerateGraphOption<'_> {
-    fn new(output_name: &str, sort: git::SortCommit) -> GenerateGraphOption {
+    fn new(output_name: &str, sort: git::SortCommit) -> GenerateGraphOption<'_> {
         GenerateGraphOption { output_name, sort }
     }
 }
@@ -1079,7 +1127,7 @@ fn generate_and_output_graph_image<P: AsRef<Path>>(path: P, option: &GenerateGra
     let graph_color_config = config::GraphColorConfig::default();
     let graph_color_set = color::GraphColorSet::new(&graph_color_config);
     let cell_width_type = graph::CellWidthType::Double;
-    let repository = git::Repository::load(path.as_ref(), option.sort);
+    let repository = git::Repository::load(path.as_ref(), option.sort).unwrap();
     let graph = graph::calc_graph(&repository);
     let image_params = graph::ImageParams::new(&graph_color_set, cell_width_type);
     let drawing_pixels = graph::DrawingPixels::new(&image_params);
@@ -1148,7 +1196,7 @@ fn create_output_dirs(path: &str) {
 }
 
 fn copy_git_dir(path: &Path, name: &str) {
-    let dst_path = format!("{}/{}", OUTPUT_DIR, name);
+    let dst_path = format!("{OUTPUT_DIR}/{name}");
     // dircpy overwrite doesn't seem to work as expected, so delete explicitly
     if Path::new(&dst_path).is_dir() {
         std::fs::remove_dir_all(&dst_path).unwrap();
@@ -1211,7 +1259,7 @@ fn compare_graph_image(option: &GenerateGraphOption) -> Result<(), String> {
         )
         .unwrap();
 
-        return Err(format!("Images are different. diff: {}", diff_file));
+        return Err(format!("Images are different. diff: {diff_file}"));
     }
 
     Ok(())
